California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 38 - SCHOOL VOUCHERS. STATE-FUNDED PRIVATE AND RELIGIOUS EDUCATION. PUBLIC SCHOOL FUNDING. INITIATIVE CONSTITUTIONAL AMENDMENT. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1224045 | NO ON 38, A COALITION OF PARENTS, EDUCATORS, BUSINESS, LABOR AND PUBLIC SAFETY | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1225973 | CALIFORNIANS FOR BETTER PUBLIC SCHOOLS AND FOR PROP 39 AND AGAINST 38 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
990640 | PROP38YES.COM, SCHOOL VOUCHERS | SUPPORT